/**
 * Library for the Mobile Processing project - http://mobile.processing.org
 *
 * Copyright (c) 2007 Shawn Van Every
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * @author  Shawn Van Every
 * 
 */

package com.mobvcasting.mvideoplayback;

import processing.core.*;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.microedition.media.*;
import javax.microedition.media.control.VideoControl;

public class MVideoPlayback 
{
	PMIDlet pMIDlet;
	
	Player mPlayer;	
	VideoControl mVideoControl;

	ByteArrayInputStream inStream;
	String mimeType;

	boolean videoPlaying = false;
	
	int videoWidth;
	int videoHeight;

	int canvasX;
	int canvasY;
	int canvasWidth;
	int canvasHeight;
	
	public MVideoPlayback(PMIDlet parent, byte[] inBytes, String mimeType) 
	{
		this.pMIDlet = parent;
		inStream = new ByteArrayInputStream(inBytes);
		this.mimeType = mimeType;
		
		initialize();
	}
	
	public void initialize()
	{
		try
		{
			mPlayer = Manager.createPlayer(inStream,mimeType);
			mPlayer.realize();

			mVideoControl = (VideoControl) mPlayer.getControl("VideoControl");
			mVideoControl.initDisplayMode(VideoControl.USE_DIRECT_VIDEO, pMIDlet.getCanvas());

            videoWidth = mVideoControl.getSourceWidth();
            videoHeight = mVideoControl.getSourceHeight();
                        
            canvasX = 0;
            canvasY = 0;
            canvasWidth = videoHeight;
            canvasHeight = videoWidth;
		}
		catch (MediaException e)
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
		catch (IOException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		}
	}
	
	public void playVideo()
	{
		try
		{
			mPlayer.start();
			
			videoPlaying = true;
		} 
		catch (MediaException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
	}

	public void stopVideo() 
	{
		try 
		{
			mPlayer.stop();
	
			videoPlaying = false;
		}
		catch (MediaException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
	}

	public void showPlayer(int x, int y, int w, int h)
	{
		try
		{
			mVideoControl.setVisible(true);			
		
			mVideoControl.setDisplayLocation(x, y);
			mVideoControl.setDisplaySize(w, h);
		} 
		catch (MediaException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		}		
	}
	
	public void closePlayer()
	{
		mVideoControl.setVisible(false);
		mPlayer.close();		
	}
}